@@ -8,8 +8,8 @@ from segregation.spatial import AbsoluteClustering
 class Absolute_Clustering_Tester(unittest.TestCase):
     def test_Absolute_Clustering(self):
         s_map = gpd.read_file(load_example("Sacramento1").get_path("sacramentot2.shp"))
-        df = s_map[['geometry', 'HISP_', 'TOT_POP']]
-        index = AbsoluteClustering(df, 'HISP_', 'TOT_POP')
+        df = s_map[['geometry', 'HISP', 'TOT_POP']]
+        index = AbsoluteClustering(df, 'HISP', 'TOT_POP')
         np.testing.assert_almost_equal(index.statistic, 0.005189287311955573)
 
 
